diff --git a/core/modules/views/lib/Drupal/views/Plugin/views/argument/Formula.php b/core/modules/views/lib/Drupal/views/Plugin/views/argument/Formula.php
index 89adc6b..51ea935 100644
--- a/core/modules/views/lib/Drupal/views/Plugin/views/argument/Formula.php
+++ b/core/modules/views/lib/Drupal/views/Plugin/views/argument/Formula.php
@@ -52,7 +52,7 @@ function summary_query() {
 
     // Add the field.
     $this->base_alias = $this->name_alias = $this->query->add_field(NULL, $formula, $this->field);
-    $this->query->set_count_field(NULL, $formula, $this->field);
+    $this->query->setFieldCount(NULL, $formula, $this->field);
 
     return $this->summaryBasics(FALSE);
   }
diff --git a/core/modules/views/lib/Drupal/views/Plugin/views/argument/String.php b/core/modules/views/lib/Drupal/views/Plugin/views/argument/String.php
index ccb4d54..4a6999f 100644
--- a/core/modules/views/lib/Drupal/views/Plugin/views/argument/String.php
+++ b/core/modules/views/lib/Drupal/views/Plugin/views/argument/String.php
@@ -157,13 +157,13 @@ function summary_query() {
     if (empty($this->options['glossary'])) {
       // Add the field.
       $this->base_alias = $this->query->add_field($this->tableAlias, $this->realField);
-      $this->query->set_count_field($this->tableAlias, $this->realField);
+      $this->query->setFieldCount($this->tableAlias, $this->realField);
     }
     else {
       // Add the field.
       $formula = $this->getFormula();
       $this->base_alias = $this->query->add_field(NULL, $formula, $this->field . '_truncated');
-      $this->query->set_count_field(NULL, $formula, $this->field, $this->field . '_truncated');
+      $this->query->setFieldCount(NULL, $formula, $this->field, $this->field . '_truncated');
     }
 
     $this->summary_name_field();
diff --git a/core/modules/views/lib/Drupal/views/Plugin/views/query/Sql.php b/core/modules/views/lib/Drupal/views/Plugin/views/query/Sql.php
index 9534f1d..2fdd766 100644
--- a/core/modules/views/lib/Drupal/views/Plugin/views/query/Sql.php
+++ b/core/modules/views/lib/Drupal/views/Plugin/views/query/Sql.php
@@ -167,7 +167,7 @@ function set_distinct($value = TRUE) {
   /**
    * Set what field the query will count() on for paging.
    */
-  function set_count_field($table, $field, $alias = NULL) {
+  public function setFieldCount($table, $field, $alias = NULL) {
     if (empty($alias)) {
       $alias = $table . '_' . $field;
     }

diff --git a/core/modules/views/lib/Drupal/views/Plugin/views/argument/ArgumentPluginBase.php b/core/modules/views/lib/Drupal/views/Plugin/views/argument/ArgumentPluginBase.php
index 2f83540..47f3372 100644
--- a/core/modules/views/lib/Drupal/views/Plugin/views/argument/ArgumentPluginBase.php
+++ b/core/modules/views/lib/Drupal/views/Plugin/views/argument/ArgumentPluginBase.php
@@ -798,7 +798,7 @@ function default_summary() {
    * - add_groupby: group on this field in order to create summaries.
    * - add_field: add a 'num_nodes' field for the count. Usually it will
    *   be a count on $view->base_field
    * - set_count_field: Reset the count field so we get the right paging.
    *
    * @return
    *   The alias used to get the number of records (count) for this entry.
@@ -859,7 +859,7 @@ public function summaryBasics($count_field = TRUE) {
     $this->query->add_groupby($this->name_alias);
 
     if ($count_field) {
-      $this->query->set_count_field($this->tableAlias, $this->realField);
+      $this->query->setFieldCount($this->tableAlias, $this->realField);
     }
 
     $this->count_alias = $count_alias;
@@ -798,7 +798,7 @@ function default_summary() {
    * - add_field: add a 'num_nodes' field for the count. Usually it will
    *   be a count on $view->base_field
-   * - set_count_field: Reset the count field so we get the right paging.
+   * - setFieldCount: Reset the count field so we get the right paging.
    *
    * @return